@@ -16,7 +16,7 @@ print(':: CPU_NUM: %s' % os.getenv('CPU_NUM'))
 print(':: FLAGS_eager_delete_tensor_gb: %s' % os.getenv('FLAGS_eager_delete_tensor_gb'))
 print(':: CUDA_VISIBLE_DEVICES: %s' % os.getenv('CUDA_VISIBLE_DEVICES'))
 
-_IN_AI_STUDIO = 'aistudio' == getpass.getuser()
+_IN_AI_STUDIO = getpass.getuser() in ['aistudio', 'paddle']
 print(':: IN_AI_STUDIO: %s' % _IN_AI_STUDIO)
 
 if _IN_AI_STUDIO:
@@ -76,7 +76,7 @@ class PaddleWrap(object):
             batch_size=32,
             log_interval=10,
             eval_interval=50,
-            checkpoint_dir='../app/ckpt_model',
+            checkpoint_dir='ckpt_model',
             strategy=self.strategy)
 
         # hub.ImageClassifierTask通过输入特征，label与迁移的类别数，可以生成适用于图像分类的迁移任务ImageClassifierTask。
